[Pkg-javascript-commits] [pdf.js] 169/207: use getBytes() instead of looping over getByte()

David Prévot taffit at moszumanska.debian.org
Mon Jul 28 15:36:44 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository pdf.js.

commit fc73e2e17354d5e5682f956da35ad73ccfa3d710
Author: fkaelberer <o_0_o at gmx.de>
Date:   Fri Jun 27 09:09:54 2014 +0200

    use getBytes() instead of looping over getByte()
---
 src/core/core.js   | 10 +++-------
 src/core/stream.js | 10 ++++------
 2 files changed, 7 insertions(+), 13 deletions(-)

diff --git a/src/core/stream.js b/src/core/stream.js
index 406d4d9..6a17214 100644
--- a/src/core/stream.js
+++ b/src/core/stream.js
@@ -539,12 +539,10 @@ var FlateStream = (function FlateStreamClosure() {
           this.eof = true;
         }
       } else {
-        for (var n = bufferLength; n < end; ++n) {
-          if ((b = str.getByte()) === -1) {
-            this.eof = true;
-            break;
-          }
-          buffer[n] = b;
+        var block = str.getBytes(blockLen);
+        buffer.set(block, bufferLength);
+        if (block.length < blockLen) {
+          this.eof = true;
         }
       }
       return;

diff --git a/src/core/core.js b/src/core/core.js
index e3a8210..f012b27 100644
--- a/src/core/core.js
+++ b/src/core/core.js
@@ -14,8 +14,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-/* globals assert, calculateMD5, Catalog, Dict, error, info, isArray,
-           isArrayBuffer, isName, isStream, isString, createPromiseCapability,
+/* globals assert, bytesToString, calculateMD5, Catalog, Dict, error, info,
+           isArray, isArrayBuffer, isName, isStream, isString,
            Linearization, NullStream, PartialEvaluator, shadow, Stream, Lexer,
            StreamsSequenceStream, stringToPDFString, stringToBytes, Util, XRef,
            MissingDataException, Promise, Annotation, ObjectLoader, OperatorList
@@ -301,14 +301,10 @@ var PDFDocument = (function PDFDocumentClosure() {
   function find(stream, needle, limit, backwards) {
     var pos = stream.pos;
     var end = stream.end;
-    var strBuf = [];
     if (pos + limit > end) {
       limit = end - pos;
     }
-    for (var n = 0; n < limit; ++n) {
-      strBuf.push(String.fromCharCode(stream.getByte()));
-    }
-    var str = strBuf.join('');
+    var str = bytesToString(stream.getBytes(limit));
     stream.pos = pos;
     var index = backwards ? str.lastIndexOf(needle) : str.indexOf(needle);
     if (index == -1) {
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-javascript/pdf.js.git



More information about the Pkg-javascript-commits mailing list